@@ -31,8 +31,8 @@ import collections
 import dataclasses
 import re
 from itertools import chain
-from typing import (cast, Dict, FrozenSet, Iterable, List, Mapping, Optional,
-                    Sequence, Set, Tuple, Union)
+from typing import (cast, Dict, FrozenSet, Iterable, List, Mapping,
+                    ClassVar, Optional, Sequence, Set, Tuple, Union)
 
 from google.api import annotations_pb2      # type: ignore
 from google.api import client_pb2
@@ -855,6 +855,26 @@ class Method:
         )
 
 
+@dataclasses.dataclass(frozen=True)
+class CommonResource:
+    type_name: str
+    pattern: str
+
+    @utils.cached_property
+    def message_type(self):
+        message_pb = descriptor_pb2.DescriptorProto()
+        res_pb = message_pb.options.Extensions[resource_pb2.resource]
+        res_pb.type = self.type_name
+        res_pb.pattern.append(self.pattern)
+
+        return MessageType(
+            message_pb=message_pb,
+            fields={},
+            nested_enums={},
+            nested_messages={},
+        )
+
+
 @dataclasses.dataclass(frozen=True)
 class Service:
     """Description of a service (defined with the ``service`` keyword)."""
@@ -864,6 +884,33 @@ class Service:
         default_factory=metadata.Metadata,
     )
 
+    common_resources: ClassVar[Sequence[CommonResource]] = dataclasses.field(
+        default=(
+            CommonResource(
+                "cloudresourcemanager.googleapis.com/Project",
+                "projects/{project}",
+            ),
+            CommonResource(
+                "cloudresourcemanager.googleapis.com/Organization",
+                "organizations/{organization}",
+            ),
+            CommonResource(
+                "cloudresourcemanager.googleapis.com/Folder",
+                "folders/{folder}",
+            ),
+            CommonResource(
+                "cloudbilling.googleapis.com/BillingAccount",
+                "billingAccounts/{billing_account}",
+            ),
+            CommonResource(
+                "locations.googleapis.com/Location",
+                "projects/{project}/locations/{location}",
+            ),
+        ),
+        init=False,
+        compare=False,
+    )
+
     def __getattr__(self, name):
         return getattr(self.service_pb, name)
 
@@ -965,7 +1012,7 @@ class Service:
     @utils.cached_property
     def resource_messages(self) -> FrozenSet[MessageType]:
         """Returns all the resource message types used in all
-        request fields in the service."""
+        request and response fields in the service."""
         def gen_resources(message):
             if message.resource_path:
                 yield message
@@ -975,9 +1022,14 @@ class Service:
                     yield type_
 
         return frozenset(
-            resource_msg
+            msg
             for method in self.methods.values()
-            for resource_msg in gen_resources(method.input)
+            for msg in chain(
+                gen_resources(method.input),
+                gen_resources(
+                    method.lro.response_type if method.lro else method.output
+                ),
+            )
         )
 
     @utils.cached_property
