@@ -22,6 +22,7 @@ from gapic.utils.filename import to_valid_filename
 from gapic.utils.filename import to_valid_module_name
 from gapic.utils.lines import sort_lines
 from gapic.utils.lines import wrap
+from gapic.utils.options import Options
 from gapic.utils.reserved_names import RESERVED_NAMES
 from gapic.utils.rst import rst
 
@@ -31,6 +32,7 @@ __all__ = (
     'doc',
     'empty',
     'nth',
+    'Options',
     'partition',
     'RESERVED_NAMES',
     'rst',
